%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This program solves for the steady state information structure under RI with
% discounted information costs for the GE pricing example in Section 5.1 of Miao, Wu, and Young (2020).
% Study the impact of shock persistence
% The model is adapted from Mackowiak and Wiederholt (2009) without strategic complementarity
% 
% 
%% @ Written by Jianjun Miao. Email: miaoj@bu.edu
% Department of Economics, Boston University
% When using this code, please cite 
% Miao, Jianjun and Jieran Wu, 2020, A Matlab Toolbox to Solve Dynamic Multivariate RI Problems in the LQG Framework, working paper, Boston University
% Miao, Jianjun, Jieran Wu, and Eric Young, 2020, Multivariate Rational Inattention, working paper, Boston University
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

close all
clear all
global lambda rho_1 rho_2 sigma_1 sigma_2 alpha_2 alpha_3 beta


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Baseline parameter values
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
lambda = 0.2; %Information cost parameter scaled by 100 
rho_1 = 0.95;% 0.95;%0.9; % persistence of idiosyncratic shock
rho_2 = 0.95; %0.95;%0.8; % persistence of aggregate demand shock
sigma_1 = 1; % scaled by 10, 10 percent S.D. of idiosyncratic innovation 
sigma_2 = 0.1; % scaled by 10, 1 percent S.D. of aggregate innovation
sigmau1 = sigma_1/sqrt(1-rho_1^2); %unconditional variance
sigmau2 = sigma_2/sqrt(1-rho_2^2); %unconditional variance

alpha_2 = 1; % No strategic complementarity
alpha_3 = 1; % profit-maximizing price reponse to idiosyncratic shock
beta = 0.95; 

PERIODS=20;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Comparative statics for the persistence of idiosyncratic shock

rho2 =0.95;

rho_1 = 0.4
sigma_1 = sigmau1*sqrt(1-rho_1^2); %Keep uncondition variance fixed
PriceNSC1
y1 = armairf(ar0,ma0,'NumObs',20); %IRF to aggregate shock
pi1 = maexpan_pi(1,1:PERIODS);  %IRF to idiosyncratic shock
disp('Signal form')
C1=C

rho_1=0.7
sigma_1=sigmau1*sqrt(1-rho_1^2);
PriceNSC1
y2 = armairf(ar0,ma0,'NumObs',20);
pi2 = maexpan_pi(1,1:PERIODS);
disp('Signal form')
C2=C

rho_1 = 0.95
sigma_1=sigmau1*sqrt(1-rho_1^2);
PriceNSC1
y3=armairf(ar0,ma0,'NumObs',20);
pi3 = maexpan_pi(1,1:PERIODS);
disp('Signal form')
C3=C



t=0:19;

figure

subplot(2,2,1)
plot(t,y1(1:20),t,y2(1:20),'--',t,y3(1:20),'-*')
lgd=legend('\rho_i = 0.5','\rho_i = 0.7','\rho_i = 0.95','Location','northeast');
lgd.FontSize=7;
xlabel('Periods')
title('IRF to aggregate shock')


%figure
subplot(2,2,2)
plot(t,pi1(1:20),t,pi2(1:20),'--',t,pi3(1:20),'-*')
lgd=legend('\rho_i = 0.5','\rho_i = 0.7','\rho_i = 0.95','Location','northeast');
lgd.FontSize=7;
xlabel('Periods')

title('IRF to idiosyncratic shock')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Comparative statics for the persistence of aggregate shock

rho_1 = 0.95;

rho_2 = 0.4
sigma_2 = sigmau2*sqrt(1-rho_2^2);
PriceNSC1
y21=armairf(ar0,ma0,'NumObs',20);
pi21 = maexpan_pi(1,1:PERIODS);

rho_2 = 0.7
sigma_2=sigmau2*sqrt(1-rho_2^2);
PriceNSC1
y22=armairf(ar0,ma0,'NumObs',20);
pi22 = maexpan_pi(1,1:PERIODS);

rho_2=0.95
sigma_2=sigmau2*sqrt(1-rho_2^2);
PriceNSC1
y23=armairf(ar0,ma0,'NumObs',20);
pi23 = maexpan_pi(1,1:PERIODS);

t=0:19;

%figure
subplot(2,2,3)
plot(t,y21(1:20),t,y22(1:20),'--',t,y23(1:20),'-*')
lgd=legend('\rho_a = 0.4','\rho_a = 0.7','\rho_a = 0.95','Location','northeast');
lgd.FontSize=7;
xlabel('Periods')
title('IRF to aggregate shock')

%figure

subplot(2,2,4)
plot(t,pi21(1:20),t,pi22(1:20),'--',t,pi23(1:20),'-*')
lgd=legend('\rho_a = 0.4','\rho_a = 0.7','\rho_a = 0.95','Location','northeast');
lgd.FontSize=7;
xlabel('Periods')

title('IRF to idiosyncratic shock')
%print -depsc figRhoNSC.eps
