%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This program solves for the steady state information structure under RI with
% discounted information costs for the GE pricing example in Section 5.1 of Miao, Wu, and Young (2020).
% Study the impact of shock volatility
% The model is adapted from Mackowiak and Wiederholt (2009) without strategic complementarity
% 
% 
%% @ Written by Jianjun Miao. Email: miaoj@bu.edu
% Department of Economics, Boston University
% When using this code, please cite 
% Miao, Jianjun and Jieran Wu, 2020, A Matlab Toolbox to Solve Dynamic Multivariate RI Problems in the LQG Framework, working paper, Boston University
% Miao, Jianjun, Jieran Wu, and Eric Young, 2020, Multivariate Rational Inattention, working paper, Boston University
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
close all
clear all
global lambda rho_1 rho_2 sigma_1 sigma_2 alpha_2 alpha_3 beta


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Baseline parameter values
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
lambda=0.2; %Information cost parameter scaled by 100 
rho_1 = 0.95;% 0.95;%0.9; % persistence of idiosyncratic shock
rho_2 = 0.95; %0.95;%0.8; % persistence of aggregate demand shock
sigma_1 = 1; % scaled by 10, 10 percent S.D. of idiosyncratic innovation 
sigma_2 = 0.1; % scaled by 10, 1 percent S.D. of aggregate innovation

alpha_2 = 1; % No strategic complementarity
alpha_3 = 1; % profit-maximizing price reponse to idiosyncratic shock

beta = 0.95;

PERIODS=20;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Comparative statics for the idiosyncratic volatility

sigma_1 = 0.3
PriceNSC1
y1=armairf(ar0,ma0,'NumObs',20); %IRF to aggregate shock
pi1 = maexpan_pi(1,1:PERIODS); %IRF to idiosyncratic shock

sigma_1=0.6
PriceNSC1
y2=armairf(ar0,ma0,'NumObs',20);
pi2 = maexpan_pi(1,1:PERIODS);

sigma_1=1
PriceNSC1
y3=armairf(ar0,ma0,'NumObs',20);
pi3 = maexpan_pi(1,1:PERIODS);

t=0:19;

figure

subplot(2,2,1)
plot(t,y1(1:20),t,y2(1:20),'--',t,y3(1:20),'-*')
lgd=legend('\sigma_i = 0.03','\sigma_i = 0.06','\sigma_i = 0.1','Location','northeast');
lgd.FontSize=7;
xlabel('Periods')
title('IRF to aggregate shock')

%figure
subplot(2,2,2)
plot(t,pi1(1:20),t,pi2(1:20),'--',t,pi3(1:20),'-*')
lgd=legend('\sigma_i = 0.03','\sigma_i = 0.06','\sigma_i = 0.1','Location','northeast');
lgd.FontSize=7;
xlabel('Periods')
title('IRF to idiosyncratic shock')


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Comparative statics for the aggregate volatility

sigma_1=1;
sigma_2 = 0.1
PriceNSC1
y1=armairf(ar0,ma0,'NumObs',20);
pi1 = maexpan_pi(1,1:PERIODS);

sigma_2= 0.8
PriceNSC1
y2=armairf(ar0,ma0,'NumObs',20);
pi2 = maexpan_pi(1,1:PERIODS);


sigma_2= 2
PriceNSC1
y3=armairf(ar0,ma0,'NumObs',20);
pi3 = maexpan_pi(1,1:PERIODS);
%full information solution

t=0:19;

%figure
subplot(2,2,3)
plot(t,y1(1:20),t,y2(1:20),'--',t,y3(1:20),'-*')
lgd=legend('\sigma_a = 0.01','\sigma_a = 0.08','\sigma_a = 0.2','Location','northeast');
lgd.FontSize=7;
xlabel('Periods')
title('IRF to aggregate shock')
%figure
subplot(2,2,4)
plot(t,pi1(1:20),t,pi2(1:20),'--',t,pi3(1:20),'-*')
lgd=legend('\sigma_a = 0.01','\sigma_a = 0.08','\sigma_a = 0.2','Location','northeast');
lgd.FontSize=7;
xlabel('Periods')
title('IRF to idiosyncratic shock')
