%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This code compute the GE pricing model in Section 5.1 of Miao, Wu, and Young (2020).
% The model is adapted from Mackowiak and Wiederholt (2009) with discounted information costs
% Solve for the steady state information structure without the signal independence assumption
% Study comparative statics with respect to the information cost parameter
% Plot impulse response functions from applying a unit size innovation shock
%
% Call PricingGE1.m
%
% @ Written by Jianjun Miao, Boston University, Email: miaoj@bu.edu 
%           and Jieran Wu, Zhejiang University, Email: jw5ya@zju.edu.cn
%
% When using this code, please cite 
% Miao, Jianjun and Jieran Wu, 2020, A Matlab Toolbox to Solve Dynamic Multivariate RI Problems in the LQG Framework, working paper, Boston University
% Miao, Jianjun, Jieran Wu, and Eric Young, 2020, Multivariate Rational Inattention, working paper, Boston University
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


close all
clear all
global lambda rho_1 rho_2 sigma_1 sigma_2 alpha_2 alpha_3 beta T

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Baseline parameter values
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
lambda = 0.2; %Information cost parameter scaled by 100 
rho_1 = 0.95; %0.4; % persistence of idiosyncratic shock
rho_2 = 0.95; %0.95;%0.8; % persistence of aggregate demand shock
sigma_1 = 1; % scaled by 10, 10 percent S.D. of idiosyncratic innovation 
sigma_2 = 0.1; % scaled by 10, 1 percent S.D. of aggregate innovation

alpha_2 = 0.15; %0.15 %profit-maximizing price reponse to aggregate shock
alpha_3 = 1; % profit-maximizing price reponse to idiosyncratic shock
beta = 0.95; % Discount factor

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

T = 20;

lambda = 0.2
PricingGE1
y1=armairf(ar0,ma0,'NumObs',T); %IRF of equilibrium price to aggregate shock

lambda = 0.4
PricingGE1
y2=armairf(ar0,ma0,'NumObs',T);

lambda = 0.6
PricingGE1
y3=armairf(ar0,ma0,'NumObs',T);


figure

subplot(1,2,1)
t=1:T;

plot(t,0.95.^(t-1),'--',t,y1(1:T),t,y2(1:T),'-.',t,y3(1:T),':','LineWidth',1.5)
lgd=legend('Full Infor','\lambda = 0.002','\lambda = 0.004','\lambda = 0.006','Location','northeast');
lgd.FontSize=7;
xlabel('time')
title('A. Impact of \lambda')


%Comparative statics with respect to strategic complementarity parameter

PricingSCIRF1 


subplot(1,2,2)
plot(t,0.95.^(t-1),'--',t,y1(1:T),t,y2(1:T),'-.',t,y3(1:T),':','LineWidth',1.5)
lgd=legend('Full infor','\alpha_2 = 0.15','\alpha_2 = 0.3','\alpha_2 = 1','Location','northeast');
lgd.FontSize=7;
xlabel('time')
title('B. Impact of \alpha_2')
%print -depsc Fig3New.eps



