% This program solve the static RI problem
% You need to install the code armafit.m
% You need to install the software CVX for algorithm 1 that can be freely 
% downloaded from the website:
% http://cvxr.com/cvx/
%
%% Input
% Sigma_pr:   Prior covariance matrix
% Omega:      Benefit matrix of information
% lambda:     Information cost parameter
% 
%% Output
%  Sigma1:    Optimal posterior covariance matrix
%  Lambda:    Lagrange multiple for the no-forgetting constraint

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Written by Jianjun Miao, Department of Economics, Boston University
% Emai: miaoj@bu.edu
%
% When using this code, please cite 
% Miao, Jianjun and Jieran Wu, 2020, A Matlab Toolbox to Solve Dynamic Multivariate RI Problems in the LQG Framework
% Miao, Jianjun, Jieran Wu, and Eric Young, 2020, Multivariate Rational Inattention Written by Jianjun Miao
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [Sigma1,Lambda] = RI_Static(lambda,Omega,Sigma_pr)
n=size(Sigma_pr,1); % State dimension
cvx_begin sdp quiet

   variable Sigma1(n,n) semidefinite
   dual variable Lambda
   minimize( trace(Omega*Sigma1)-0.5*lambda*log_det(Sigma1))  
  subject to
          Lambda: Sigma_pr>= Sigma1;  %No-forgetting constraint
 cvx_end
end
