%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This Matlab program solves for the transition dynamics 
% of the posterior covariance matrix 
% for the tracking problem in Sims Handbook example, which is also in
% Section 4 of Miao, Wu, and Young (2020).
% 
%
% @ Written by Jianjun Miao. Email: miaoj@bu.edu
% Department of Economics, Boston University
% When using this code, please cite 
% Miao, Jianjun and Jieran Wu, 2020, A Matlab Toolbox to Solve Dynamic Multivariate RI Problems in the LQG Framework, working paper, Boston University
% Miao, Jianjun, Jieran Wu, and Eric Young, 2020, Multivariate Rational Inattention, working paper, Boston University
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


global beta rho1 rho2 period lambda

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%Generate baseline parameter data

%beta = 0.9;    % Discount factor

%rho1 = 0.95;  % more persistent state
%rho2 = 0.4;  % less persistent state

sigma1 = sqrt(1-rho1^2); % Choose innovation variance to keep stationary variance at 1
sigma2 = sqrt(1-rho2^2); % Choose innovation variance to keep stationary variance at 1

%sigma2 = sqrt(0.6)
%W = [0.5^2 0.1;
%    0.1  0.8^2];

W=[sigma1^2 0;   %State noise covariance matrix
    0 sigma2^2];
A = [rho1,0;   %State transition matrix
    0,rho2];
G = [1,1];

Omega = G'*G; %Weighting matrix

%lambda = 2; % Information cost. My lambda corresponds to 2*lambda in Sims handbook example


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% Solve for the steady state
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Sigma_pr0 = A*A'+W;
Theta0 = Omega;

tic
[SigmaSS, Sigma_pr, ThetaSS, Lambda] = RI_SS_FOC(lambda,beta,A,W, Omega, Theta0, Sigma_pr0);
toc

[C,V,r] = RI_SIG(SigmaSS,Sigma_pr,ThetaSS,lambda); %Signal structure, signal dimension = rank(SNR)
K = Sigma_pr*C'*inv(C*Sigma_pr*C'+V)
disp('Initial response: GKC')
G*K*C
CN = C/C(2);
VN = V/C(2)^2;
disp('rho1; rho2;  Steady state signal weight vector;  Signal noise')
[rho1 rho2 CN, VN] 


B = zeros(2,1); %Exogenous state
F = -G; % policy function y = -F*x = G*x
T = period;
[X, u,u_full] = RI_IRF(A,B,C,F,SigmaSS,V,W,T);

irfy = u(1,:,1:2); %IRF to two structural shocks

%t=1:period;
%subplot(1,2,1)
%plot(t,u(1,:,1))
%grid on
%subplot(1,2,2)
%plot(t,u(1,:,2))
%grid on

