%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This Matlab program studies the impact of shock persistence 
% for the pricing example in Sims (2011) Handbook chapter, which is also in
% Section 4 of Miao, Wu, and Young (2020).
% Call Matlab functions SimsEx_IRF.m
%
% @ Written by Jianjun Miao. Email: miaoj@bu.edu
% Department of Economics, Boston University
% When using this code, please cite 
% Miao, Jianjun and Jieran Wu, 2020, A Matlab Toolbox to Solve Dynamic Multivariate RI Problems in the LQG Framework, working paper, Boston University
% Miao, Jianjun, Jieran Wu, and Eric Young, 2020, Multivariate Rational Inattention, working paper, Boston University
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all
close all 
global beta rho1 rho2 period lambda

%Generate baseline parameter data
beta = 0.9;    % Discount factor

rho1 = 0.7;  % more persistent state
rho2 = 0.7;  % less persistent state

lambda = 2; % Information cost. My lambda corresponds to 2*lambda in Sims handbook example

period = 20;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% Solve for the steady state
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

rho1 = 0.5;
SimsEx_IRF;
irfy1=irfy;
SigmaSS

rho1 = rho2;
SimsEx_IRF;
irfy2 = irfy;
SigmaSS

rho1 = 0.9;
SimsEx_IRF;
irfy3 = irfy;
SigmaSS

t=1:period;

subplot(1,2,1)
plot(t,irfy1(1,:,1),t,irfy2(1,:,1),'--',t,irfy3(1,:,1),'-.')
legend('\rho_1=0.5','\rho_1=0.7','\rho_1=0.9')
grid on
ylim([0 0.7])
title('IRF to shock 1 (\rho_2=0.7)')
subplot(1,2,2)
plot(t,irfy1(1,:,2),t,irfy2(1,:,2),'--',t,irfy3(1,:,2),'-.')
legend('\rho_1=0.5','\rho_1=0.7','\rho_1=0.9')
ylim([0 0.7])
title('IRF to shock 2 (\rho_2=0.7)')
grid on

%print -depsc Figrho.eps