%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This Matlab program solves for the transition dynamics of the posterior covariance matrix 
% for the tracking problem in Sims Handbook example, which is also in
% Section 4 of Miao, Wu, and Young (2020).
% Call Matlab functions SimsEx_beta.m, RI_SS_FOC.m, RI_SIG.m and RI_TD_FOC.m
%
% @ Written by Jianjun Miao. Email: miaoj@bu.edu
% Department of Economics, Boston University
%
% When using this code, please cite 
% Miao, Jianjun and Jieran Wu, 2020, A Matlab Toolbox to Solve Dynamic Multivariate RI Problems in the LQG Framework, working paper, Boston University
% Miao, Jianjun, Jieran Wu, and Eric Young, 2020, Multivariate Rational Inattention, working paper, Boston University
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


clear all
close all
global beta

%% Generate baseline parameter data
beta = 0.9;    % Discount factor

rho1 = 0.95;  % more persistent state
rho2 = 0.40;  % less persistent state

%sigma1 = sqrt(0.0975); 
sigma1 = sqrt(1-rho1^2); % Choose innovation variance to keep stationary variance at 1
sigma2 = sqrt(1-rho2^2); %0.84;
W=[sigma1^2 0;   %State noise covariance matrix
    0 sigma2^2];
A = [rho1,0;   %State transition matrix
    0,rho2];
G = [1,1];
Omega = G'*G; %Weighting matrix
lambda = 4; % Information cost. My lambda corresponds to 2*lambda in Sims handbook example

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

beta =1;
SimsEx_beta;
dim1 = dim;
irfy1 = irfy;
iffyf1 = irfyf;

beta = 0.9;
SimsEx_beta
dim2 = dim;
irfy2 = irfy; 

beta = 0.5;
SimsEx_beta
dim3 = dim;
irfy3 = irfy;

time =1: 20;

subplot(1,3,1)
plot(time-1,dim1,'--',time-1,dim2,'-.',time-1,dim3,'-*') 
legend('\beta=1','\beta=0.9','\beta=0.5')
title('A. Signal dimension')
xlabel('time')

time=1:30;
subplot(1,3,2)
plot(time,irfy1(1,:,1),'--', time,irfy2(1,:,1),'-.',time,irfy3(1,:,1),'-*',time,irfyf(1,:,1));
title('B. IRF to shock 1')
legend('\beta=1','\beta=0.9','\beta=0.5','full info')
xlabel('time')

subplot(1,3,3)
plot(time,irfy1(1,:,2),'--', time,irfy2(1,:,2),'-.',time,irfy3(1,:,2),'-*',time,irfyf(1,:,2));
legend('\beta=1','\beta=0.9','\beta=0.5','full info')
title('C. IRF to shock 2')
xlabel('time')

%print -depsc FigNew2.eps
%print -dpdf FigNew2.pdf