function C = Varma2ma1(A,B,N)
% Function ARMA2MA
%
% Purpose:    Approximate VARMA(p,q) by VMA(N) with large N
%
% Format:     C = arma2ma(A,B,N)
%
% Input:      A(:,:,k)  VAR matrix coeff A(k)
%             B(:,:,k)  VMA matrix coeff B(k-1)
%
%                       y(t) = A(1)*y(t-1)+...+A(p)*y(t-p)+B(0)*e(t)+...+B(q)*e(t-q)
%
%             N         number of VMA terms
%
% Output:     C(:,:,k)  VMA matrix coeff C(k-1)
%
%                       y(t) = C(0)*e(t)+...+C(N-1)*e(t-N+1)
%
% Written by Fei Tan, Saint Louis University
% Updated: September 18, 2019

%% -------------------------------------------
%          Approximate VARMA by VMA
%---------------------------------------------

[m,n,~] = size(B);
fz = zeros(m,n,N);
for k = 0:N-1
    z = exp(-1i*2*pi*k/N);
    fz(:,:,k+1) = armaeval(z,A,B);
end
C = real(ifft(fz,[],3));    % inverse Discrete Fourier Transform (DFT)

%-------------------- END --------------------
