%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This code  verifies the static reverse water-filling solution in Lemma 3
% The benefit matrix Omega is symmetric, but may not be positive semidefinite 
%
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Written by Jianjun Miao, Department of Economics, Boston University
% Emai: miaoj@bu.edu
%
% When using this code, please cite 
% Miao, Jianjun and Jieran Wu, 2020, A Matlab Toolbox to Solve Dynamic Multivariate RI Problems in the LQG Framework, working paper, Boston University
% Miao, Jianjun, Jieran Wu, and Eric Young, 2020, Multivariate Rational Inattention, working paper, Boston University
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

close all; clear all;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Parameter values
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

n = 4; %State dimension
I = eye(n);
lambda = 4; %Information cost
Omega = eye(n); 
%Construct a symmetric matrix Omega, which may not be definite.
Omega(1,1) = -1; 
Omega(2,2) = -2;
Omega(3,3) = 4;
Omega(4,4) = 5;

disp('Eigenvalues of Omega')
eig(Omega)
Sigma_pr = eye(n); %Prior covariance matrix

cvx_solver mosek %sedumi  

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[Sigma1,Lambda] = RI_Static(lambda,Omega,Sigma_pr);
disp('Numerical solution for the posterior covariance matrix')
Sigma1

% Analytical solution in Lemma 3
weighted = sqrtm(Sigma_pr)*Omega*sqrtm(Sigma_pr);
if min(eig(Omega)) >-1e-10 %check if psd
    [U,D,v] = svd(weighted); %sigular value decomposition
  else
    [U,D] = eig(weighted); %eigendecomposition
end
disp('Analytical solution for the posterior covariance matrix by Lemma 3')
Sigma_true = sqrtm(Sigma_pr)*U/max(2/lambda*D,I)*U'*sqrtm(Sigma_pr)

